Skip to contents

Retrieves the thematic tree from the CEPALSTAT API in JSON format and returns a data frame with the hierarchical structure of indicators.

Usage

call.indicators(language.en = TRUE, progress = TRUE)

Arguments

language.en

Logical. If TRUE (default), labels are returned in English. If FALSE, labels are returned in Spanish.

progress

Logical. If TRUE (default), progress messages are displayed.

Value

A data frame with the hierarchical thematic structure of CEPALSTAT indicators. Indicator IDs are returned as character strings.

Details

The returned indicator catalogue includes provenance metadata attributes describing the retrieval conditions of the CEPALSTAT query.

Examples

# \donttest{
data.indicators <- call.indicators()
#> Downloading thematic tree from CEPALSTAT...
#> Parsing indicator hierarchy...
#> Finished downloading indicators.
data.indicators <- call.indicators(language.en = FALSE)
#> Descargando árbol temático desde CEPALSTAT...
#> Procesando jerarquía de indicadores...
#> Descarga de indicadores finalizada.
# }