Retrieves the thematic tree from the CEPALSTAT API in JSON format and returns a data frame with the hierarchical structure of indicators.
Value
A data frame with the hierarchical thematic structure of CEPALSTAT indicators and the corresponding indicator ID.
Examples
# \donttest{
data.indicators <- call.indicators()
#> Downloading thematic tree from CEPALSTAT...
#> Parsing indicator hierarchy...
#> Finished downloading indicators.
data.indicators <- call.indicators(language.en = FALSE)
#> Descargando árbol temático desde CEPALSTAT...
#> Procesando jerarquía de indicadores...
#> Descarga de indicadores finalizada.
# }