Skip to contents

Creates an interactive thematic tree of CEPALSTAT indicators using collapsibleTree, with the same visual header and footer style as viewer.indicators().

Usage

topic_map(language.en = TRUE, progress = TRUE, open.browser = FALSE)

Arguments

language.en

Logical. If TRUE (default), English labels are used. If FALSE, Spanish labels are used.

progress

Logical. If TRUE, progress messages are shown.

open.browser

Logical. If TRUE, the generated HTML is saved to a temporary file and opened in the default web browser. Defaults to FALSE.

Value

A browsable HTML widget.

Examples

# \donttest{
topic_map()
#> Preparing thematic map...
#> Downloading thematic tree from CEPALSTAT...
#> Parsing indicator hierarchy...
#> Finished downloading indicators.
#> Building interactive tree...
R interface to access, explore and visualize CEPALSTAT indicators
Available indicators: 1,697
CEPALSTAT
Statistical Data Portal and Publications
For more information about CEPALSTAT, visit https://statistics.cepal.org/portal/cepalstat/
Generated with CepalStatR
Interactive thematic map of indicators
topic_map(language.en = FALSE) #> Preparando mapa temático... #> Descargando árbol temático desde CEPALSTAT... #> Procesando jerarquía de indicadores... #> Descarga de indicadores finalizada. #> Construyendo árbol interactivo...
Interfaz en R para acceder, explorar y visualizar indicadores de CEPALSTAT
Indicadores disponibles: 1,697
CEPALSTAT
Portal de Datos y Publicaciones Estadísticas
Para más información de CEPALSTAT accede a https://statistics.cepal.org/portal/cepalstat/
Generado con CepalStatR
Mapa temático interactivo de indicadores
# }