Skip to contents

Displays an interactive HTML table for browsing the hierarchical structure of CEPALSTAT indicators using call.indicators() as backend.

Usage

viewer.indicators(
  language.en = TRUE,
  progress = TRUE,
  show_search = TRUE,
  striped = TRUE,
  bordered = FALSE,
  compact = FALSE,
  highlight = TRUE,
  full_width = TRUE,
  page_size = 15,
  open.browser = FALSE
)

Arguments

language.en

Logical. If TRUE (default), the viewer uses English labels. If FALSE, Spanish labels are used.

progress

Logical. If TRUE, progress messages are shown.

Logical. If TRUE, enables global search in the table.

striped

Logical. If TRUE, striped rows are shown.

bordered

Logical. If TRUE, table borders are shown.

compact

Logical. If TRUE, reduces row padding.

highlight

Logical. If TRUE, highlights rows on hover.

full_width

Logical. If TRUE, table uses full available width.

page_size

Integer. Number of rows to show per page.

open.browser

Logical. If TRUE, the generated HTML is saved to a temporary file and opened in the default web browser. Defaults to FALSE.

Value

A browsable HTML object containing the header and interactive table.

Examples

# \donttest{
viewer.indicators()
#> Preparing indicator viewer...
#> Downloading thematic tree from CEPALSTAT...
#> Parsing indicator hierarchy...
#> Finished downloading indicators.
R interface to access, explore and visualize CEPALSTAT indicators
Available indicators: 1,697
CEPALSTAT
Statistical Data Portal and Publications
For more information about CEPALSTAT, visit https://statistics.cepal.org/portal/cepalstat/
Generated with CepalStatR
viewer.indicators(language.en = FALSE) #> Preparando visor de indicadores... #> Descargando árbol temático desde CEPALSTAT... #> Procesando jerarquía de indicadores... #> Descarga de indicadores finalizada.
Interfaz en R para acceder, explorar y visualizar indicadores de CEPALSTAT
Indicadores disponibles: 1,697
CEPALSTAT
Portal de Datos y Publicaciones Estadísticas
Para más información de CEPALSTAT accede a https://statistics.cepal.org/portal/cepalstat/
Generado con CepalStatR
viewer.indicators(open.browser = TRUE) #> Preparing indicator viewer... #> Downloading thematic tree from CEPALSTAT... #> Parsing indicator hierarchy... #> Finished downloading indicators.
R interface to access, explore and visualize CEPALSTAT indicators
Available indicators: 1,697
CEPALSTAT
Statistical Data Portal and Publications
For more information about CEPALSTAT, visit https://statistics.cepal.org/portal/cepalstat/
Generated with CepalStatR
# }